use clap::{Args, ValueEnum};
use hound::Sample;
use image::{DynamicImage, io::Reader as ImageReader};
use std::io::{Cursor, Write};
use tool_helper::{print_warning, Error, Input};

#[derive(Args)]
pub struct Arguments {
}

pub fn convert(input: Input, output: &mut dyn Write) -> Result<(), Error> {
    let mut audio_io  = hound::WavReader::new(input)?;
    let     header    = audio_io.spec();

    if header.sample_format != hound::SampleFormat::Int ||header.bits_per_sample != 16 {
        return Err(Error::from_str("Only 16bit integer samples are supported"));
    }

    if header.channels > 1 {
        print_warning("Found more than one audio channel. First channel will be encoded.".to_owned());
    }

    let     active_channel = 1;
    let mut sample_count   = 0;
    for sample in audio_io.samples::<i16>() {
        match sample {
            Ok(sample) => {
                sample_count += 1;

                if sample_count%active_channel == 0 {
                    output.write(&sample.to_le_bytes())?;
                }
            }

            Err(error) => {
                return Err(Error::from_text(format!("Failed iterating over samples: {}", error)));
            }
        }
    }
    Ok(())
}